@@ -14,6 +14,6 @@ def chat(value):
         if("zackybot" in translated.text.lowercase()):
             new_string = "Adım, kenu-ai. r4isy tarafından yazıldım."
             return new_string
-        elif("acobot.ai" in translated.text.lowercase() or "acobot" in translated.text.lowercase())
+        elif("acobot.ai" in translated.text.lowercase() or "acobot" in translated.text.lowercase()):
         else:
             return translated.text
\ No newline at end of file
